Enhancing null providers for use in demos.

Change-Id: I079d19a98fba2312bd4b17d2e275b34f4dee6f19
diff --git a/providers/null/src/main/java/org/onosproject/provider/nil/cli/NullDeviceCommand.java b/providers/null/src/main/java/org/onosproject/provider/nil/cli/NullDeviceCommand.java
index bf08232..ef1a70e 100644
--- a/providers/null/src/main/java/org/onosproject/provider/nil/cli/NullDeviceCommand.java
+++ b/providers/null/src/main/java/org/onosproject/provider/nil/cli/NullDeviceCommand.java
@@ -25,10 +25,10 @@
 import static org.onosproject.cli.UpDownCompleter.UP;
 
 /**
  * Servers or repairs a simulated link.
  */
 @Command(scope = "onos", name = "null-device",
-        description = "Severs or repairs a simulated link")
+        description = "Downs or repairs a simulated device")
 public class NullDeviceCommand extends AbstractShellCommand {
 
     @Argument(index = 0, name = "id", description = "Device identifier",
@@ -25,10 +25,10 @@
 
 /**
- * Servers or repairs a simulated link.
+ * Downs or repairs a simulated device.
  */
 @Command(scope = "onos", name = "null-device",